==> sormap-src-V0.2.0.zip: org/dyndns/nuda/mapper/DaoHelper.java <==
package org.dyndns.nuda.mapper;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

public class DaoHelper {
	private DaoHelper() {
		// インスタンス化させない
	}
	
	private static final String	SETTER_PREFIX	= "set";
	
	/**
	 * SQL結果セットをJavaBeanに変換します
	 * 
	 * @param <D>
	 *            SQL結果セット格納Beanクラス
	 * @param resultSet
	 *            SQL結果セット
	 * @param cls
	 *            SQL結果セット格納Beanクラスオブジェクト
	 * @return SQL結果セット格納Bean
	 */
	public static <D> D convertResult(final ResultSet resultSet,
			final Class<D> cls) {
		
		try {
			
			// clsがプリミティブの場合
			if (cls == Integer.class) {
				// intの場合
				Object result = resultSet.getInt(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == String.class) {
				// Stringの場合
				Object result = resultSet.getString(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == java.util.Date.class) {
				// java.util.Dateの場合
				java.sql.Date result = resultSet.getDate(1);
				
				D result0 = cls.cast(new java.util.Date(result.getTime()));
				return result0;
			} else if (cls == java.sql.Date.class) {
				// java.util.Dateの場合
				Object result = resultSet.getDate(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == Long.class) {
				// longの場合
				Object result = resultSet.getLong(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == Double.class) {
				// doubleの場合
				Object result = resultSet.getDouble(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == BigInteger.class) {
				// BigIntegerの場合
				// 処理しない
				throw new SQLException("タイプ:BigIntegerはサポートされておりません");
			} else if (cls == BigDecimal.class) {
				// BigDecimalの場合
				Object result = resultSet.getBigDecimal(1);
				D result0 = cls.cast(result);
				
				return result0;
			} else if (cls == Boolean.class) {
				// booleanの場合
				Object result = resultSet.getBoolean(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else {
				// それ以外の場合
				// DをJavaBeansとして処理する
				
				// ResultSetMetadataの取得
				ResultSetMetaData metadata = resultSet.getMetaData();
				List<String> columnList = new ArrayList<String>();
				for (int i = 1; i <= metadata.getColumnCount(); i++) {
					columnList.add(metadata.getColumnLabel(i));
				}
				
				// publicなメソッドを抽出する
				Method[] methods = cls.getDeclaredMethods();
				D beans = cls.newInstance();
				for (Method aMethod : methods) {
					// メソッド名が「set」から始まっていた場合を対象とする
					String methodName = aMethod.getName();
					if (!methodName.startsWith(SETTER_PREFIX)) {
						continue;
					}
					
					// キャメルケース変換処理
					// メソッド名から先頭の「set」を取り除き
					// 先頭文字を小文字に変換する
					String operateParamName = methodName.substring(3,
							methodName.length());
					String startChar = operateParamName.substring(0, 1);
					startChar = startChar.toLowerCase();
					operateParamName = operateParamName.substring(1,
							operateParamName.length());
					
					String realName = startChar + operateParamName;
					
					int matchCount = 0;
					for (String aColumn : columnList) {
						if (realName.equals(aColumn)) {
							matchCount++;
						}
					}
					
					// Beanのプロパティ名が取得カラムに存在しない場合はスキップする
					if (matchCount == 0) {
						continue;
					}
					
					Class<?>[] paramClasses = aMethod.getParameterTypes();
					if (paramClasses != null && paramClasses.length == 1) {
						// パラメタが存在し、その個数が１の場合のみ処理の対象とする
						
						Class<?> targetClass = paramClasses[0];
						
						if (targetClass == int.class) {
							// intの場合
							aMethod.invoke(beans, resultSet.getInt(realName));
							
						} else if (targetClass == String.class) {
							// Stringの場合
							aMethod.invoke(beans, resultSet.getString(realName));
							
						} else if (targetClass == java.util.Date.class) {
							// java.util.Dateの場合
							
							java.sql.Date d = resultSet.getDate(realName);
							
							aMethod.invoke(beans,
									new java.util.Date(d.getTime()));
						} else if (targetClass == java.sql.Date.class) {
							// java.sql.Dateの場合
							
							java.sql.Date d = resultSet.getDate(realName);
							
							aMethod.invoke(beans, d);
						} else if (targetClass == long.class) {
							// longの場合
							aMethod.invoke(beans, resultSet.getLong(realName));
							
						} else if (targetClass == double.class) {
							// doubleの場合
							aMethod.invoke(beans, resultSet.getDouble(realName));
							
						} else if (targetClass == BigInteger.class) {
							// BigIntegerの場合
							// 処理しない
							
						} else if (targetClass == BigDecimal.class) {
							// BigDecimalの場合
							aMethod.invoke(beans,
									resultSet.getBigDecimal(realName));
							
						} else if (targetClass == boolean.class) {
							// booleanの場合
							aMethod.invoke(beans,
									resultSet.getBoolean(realName));
							
						} else {
							// それ以外の場合(無視)
						}
					}
				}
				
				return beans;
			}
			
		} catch (InstantiationException e) {
			//			LoggerFactory.getLogger("DaoHelper").error(
			//					"InstantiationException", e);
			
			return null;
		} catch (IllegalAccessException e) {
			//			LoggerFactory.getLogger("DaoHelper").error(
			//					"IllegalAccessException", e);
			
			return null;
		} catch (IllegalArgumentException e) {
			//			LoggerFactory.getLogger("DaoHelper").error(
			//					"IllegalArgumentException", e);
			
			return null;
		} catch (InvocationTargetException e) {
			//			LoggerFactory.getLogger("DaoHelper").error(
			//					"InvocationTargetException", e);
			
			return null;
		} catch (SQLException e) {
			//			LoggerFactory.getLogger("DaoHelper").error("SQLException", e);
			
			return null;
		}
		
	}
}

==> sormap-src-V0.3.1.zip: org/dyndns/nuda/mapper/DaoHelper.java <==
package org.dyndns.nuda.mapper;

import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

/**
 * JDBC結果セットからJavaBeansへの変換を行うためのユーティリティクラスです
 * 
 * @author nkoseki
 * 
 */
public class DaoHelper {
	private DaoHelper() {
		// インスタンス化させない
	}
	
	private static final String	SETTER_PREFIX	= "set";
	
	/**
	 * SQL結果セットをJavaBeanに変換します
	 * 
	 * @param <D>
	 *            SQL結果セット格納Beanクラス
	 * @param resultSet
	 *            SQL結果セット
	 * @param cls
	 *            SQL結果セット格納Beanクラスオブジェクト
	 * @return SQL結果セット格納Bean
	 */
	public static <D> D convertResult(final ResultSet resultSet,
			final Class<D> cls) {
		
		try {
			
			// clsがプリミティブの場合
			if (cls == Integer.class) {
				// intの場合
				Object result = resultSet.getInt(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == String.class) {
				// Stringの場合
				Object result = resultSet.getString(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == java.util.Date.class) {
				// java.util.Dateの場合
				java.sql.Date result = resultSet.getDate(1);
				
				D result0 = cls.cast(new java.util.Date(result.getTime()));
				return result0;
			} else if (cls == java.sql.Date.class) {
				// java.util.Dateの場合
				Object result = resultSet.getDate(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == Long.class) {
				// longの場合
				Object result = resultSet.getLong(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == Double.class) {
				// doubleの場合
				Object result = resultSet.getDouble(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else if (cls == BigInteger.class) {
				// BigIntegerの場合
				// 処理しない
				throw new SQLException("タイプ:BigIntegerはサポートされておりません");
			} else if (cls == BigDecimal.class) {
				// BigDecimalの場合
				Object result = resultSet.getBigDecimal(1);
				D result0 = cls.cast(result);
				
				return result0;
			} else if (cls == Boolean.class) {
				// booleanの場合
				Object result = resultSet.getBoolean(1);
				D result0 = cls.cast(result);
				return result0;
				
			} else {
				// それ以外の場合
				// DをJavaBeansとして処理する
				
				// ResultSetMetadataの取得
				ResultSetMetaData metadata = resultSet.getMetaData();
				List<String> columnList = new ArrayList<String>();
				for (int i = 1; i <= metadata.getColumnCount(); i++) {
					columnList.add(metadata.getColumnLabel(i));
				}
				
				// publicなメソッドを抽出する
				Method[] methods = cls.getDeclaredMethods();
				D beans = cls.newInstance();
				for (Method aMethod : methods) {
					// メソッド名が「set」から始まっていた場合を対象とする
					String methodName = aMethod.getName();
					if (!methodName.startsWith(SETTER_PREFIX)) {
						continue;
					}
					
					// キャメルケース変換処理
					// メソッド名から先頭の「set」を取り除き
					// 先頭文字を小文字に変換する
					String operateParamName =
						methodName.substring(3, methodName.length());
					String startChar = operateParamName.substring(0, 1);
					startChar = startChar.toLowerCase();
					operateParamName =
						operateParamName
							.substring(1, operateParamName.length());
					
					String realName = startChar + operateParamName;
					
					int matchCount = 0;
					for (String aColumn : columnList) {
						if (realName.equals(aColumn)) {
							matchCount++;
							break;
						}
					}
					
					if (matchCount == 0) {
						// JavaBeansの各フィールドがすべて大文字の場合
						for (String aColumn : columnList) {
							if (realName.toUpperCase().equals(aColumn)) {
								realName = realName.toUpperCase();
								matchCount++;
								break;
							}
						}
					}
					
					if (matchCount == 0) {
						
						continue;
					}
					
					Class<?>[] paramClasses = aMethod.getParameterTypes();
					if (paramClasses != null && paramClasses.length == 1) {
						// パラメタが存在し、その個数が１の場合のみ処理の対象とする
						
						Class<?> targetClass = paramClasses[0];
						
						if (targetClass == int.class) {
							// intの場合
							aMethod.invoke(beans, resultSet.getInt(realName));
							
						} else if (targetClass == String.class) {
							// Stringの場合
							aMethod
								.invoke(beans, resultSet.getString(realName));
							
						} else if (targetClass == java.util.Date.class) {
							// java.util.Dateの場合
							
							java.sql.Date d = resultSet.getDate(realName);
							
							aMethod.invoke(
								beans,
								new java.util.Date(d.getTime()));
						} else if (targetClass == java.sql.Date.class) {
							// java.sql.Dateの場合
							
							java.sql.Date d = resultSet.getDate(realName);
							
							aMethod.invoke(beans, d);
						} else if (targetClass == long.class) {
							// longの場合
							aMethod.invoke(beans, resultSet.getLong(realName));
							
						} else if (targetClass == double.class) {
							// doubleの場合
							aMethod
								.invoke(beans, resultSet.getDouble(realName));
							
						} else if (targetClass == BigInteger.class) {
							// BigIntegerの場合
							// 処理しない
							
						} else if (targetClass == BigDecimal.class) {
							// BigDecimalの場合
							aMethod.invoke(
								beans,
								resultSet.getBigDecimal(realName));
							
						} else if (targetClass == boolean.class) {
							// booleanの場合
							aMethod.invoke(
								beans,
								resultSet.getBoolean(realName));
							
						} else {
							// それ以外の場合(無視)
						}
					}
				}
				
				return beans;
			}
			
		} catch (InstantiationException e) {
			return null;
		} catch (IllegalAccessException e) {
			return null;
		} catch (IllegalArgumentException e) {
			return null;
		} catch (InvocationTargetException e) {
			return null;
		} catch (SQLException e) {
			return null;
		}
		
	}
}
